===============================
PoshSplice
===============================

.. image:: https://img.shields.io/travis/olgabot/poshsplice.svg
        :target: https://travis-ci.org/olgabot/poshsplice

.. image:: https://img.shields.io/pypi/v/poshsplice.svg
        :target: https://pypi.python.org/pypi/poshsplice


Python Boilerplate contains all the boilerplate you need to create a Python package.

* Free software: BSD license
* Documentation: https://poshsplice.readthedocs.org.

Features
--------

* TODO
